--new color coding

-- labels
TITCURRTRACK_SHOW_ANNOUNCE = "Show Announcement";
TITCURRTRACK_SHOW_LOG = "Show Logging";
TITCURRTRACK_SHOW_SUMMARY = "Show Session Summary";

-- globals
TITCURRTRACK_ID =  "CurrTrack";
TITCURRTRACK_VERSION = "1.0.3 for Cataclysm";
TITCURRTRACK_BUTTON_TEXT = "CurrencyTracker";

-- local
local TITCURRTRACK_TOOLTIP_TEXT = "";
local TITCURRTRACK_TTS = {};
local TITCURRTRACK_TIME = GetTime();
local TITCURRTRACK_VALUES = {};
local TITCURRTRACK_VSIZE = 0;


-- initializing
function TitanPanelCurrTrackButton_OnLoad(self)
	self.registry = {
		id = TITCURRTRACK_ID,
		menuText = TITCURRTRACK_ID, 
		version = TITCURRTRACK_VERSION,
		buttonTextFunction = "TitanPanelCurrTrack_GetButtonText", 
		tooltipTitle = "Titan CurrTrack"..TITCURRTRACK_VERSION,
		tooltipTextFunction = "TitanPanelCurrTrack_GetToolTipText", 
		category = "Information",
		savedVariables = {
			ShowAnnounce = 1, 
			ShowLog = 1,
			ShowSummary = 1,
			TokenHeaders = { "" }
		}
	};	
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
	self:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
end

-- event handling
function TitanPanelCurrTrackButton_OnClick(self, button)
     if (button == "LeftButton") then
	     ToggleCharacter("TokenFrame");
     end
     if (button == "RightButton") then
	     TitanPanelRightClickMenu_PrepareCurrTrackMenu(self);
     end
end

function TitanPanelCurrTrackButton_OnEvent(self, event, ...)	
	--print(event);
	TitanPanelButton_UpdateTooltip();
	TitanPanelButton_UpdateButton(TITCURRTRACK_ID);
end

-- for titan to get the displayed text
function TitanPanelCurrTrack_GetButtonText(id)
	TitanPanelCurrTrack_Refresh();
	return TITCURRTRACK_BUTTON_TEXT;
end

-- for titan tool tip text building
function TitanPanelCurrTrack_GetToolTipText()
	local display="";
	local tooltip="|r";
	local name, isHeader, isExpanded, isUnused, isWatched, count, cCount, PVPIndex;
	cCount = GetCurrencyListSize();
	for index=1, cCount do 
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID = GetCurrencyListInfo(index);
		if (isHeader) then
			tooltip = tooltip..TitanUtils_GetHighlightText(name).."\n";
		end
		if (count~=0) then
			display=strconcat(" ",name,"\t",count," |T"..icon..":18|t");
			tooltip=strconcat(tooltip,display,"|r\n");
		end
	end 
	if(TitanGetVar(TITCURRTRACK_ID, "ShowSummary") == 1) then
		local timeonline =  GetTime() -	TITCURRTRACK_TIME;
		local humantime = "";

		if (timeonline < 60) then
			humantime = "< 1 Mn";
		else 
			humantime = floor(timeonline / 60);
			if(humantime < 60) then
				humantime = humantime.." Mn";
			else
				local hours = floor(humantime / 60);
				local mins = floor((timeonline - (hours * 60 * 60)) / 60);
				humantime = hours.." Hr "..mins.." Mn";
			end
		end
		tooltip = tooltip.."\n"..TitanUtils_GetHighlightText("Session Summary:");
		tooltip = tooltip.."\t"..TitanUtils_GetNormalText("Duration: "..humantime);

		for f, v in pairs(TITCURRTRACK_TTS) do
			local TPH = floor(v / (timeonline / 60 / 60));
			if(TPH > 0) then
				tooltip = tooltip.."\n "..f.." : "..TitanUtils_GetGreenText(TPH).." perHour\t Total: "..TitanUtils_GetGreenText(v);
			else
				tooltip = tooltip.."\n "..f.." : "..TitanUtils_GetRedText(TPH).." perHour\t Total: "..TitanUtils_GetRedText(v);
			end
		end
	end
	final_tooltip=tooltip;
	return ""..final_tooltip;    	
end

function TitanPanelRightClickMenu_AddTitle2(title, level)
	if (title) then
		local info = {};
		info.text = title;
		info.notClickable = 1;
		info.isTitle = 1;
       		info.notCheckable = true;
		UIDropDownMenu_AddButton(info, level);
	end
end


function TitanPanelRightClickMenu_AddToggleVar2(text, id, var, toggleTable)
	local info = {};
	info.text = text;
	info.value = {id, var, toggleTable};
	info.func = function()
		TitanPanelRightClickMenu_ToggleVar({id, var, toggleTable})
	end
	info.checked = TitanGetVar(id, var);
	info.keepShownOnClick = 1;
	UIDropDownMenu_AddButton(info, 2);
end

function TitanPanelRightClickMenu_AddToggleIcon2(id)
	TitanPanelRightClickMenu_AddToggleVar2("Show Icon", id, "ShowIcon");
end

function TitanPanelRightClickMenu_AddSpacer2(level)
	local info = {};
	info.disabled = 1;
       	info.notCheckable = true;
	UIDropDownMenu_AddButton(info, level);
end


-- this method builds the right-click menus
function TitanPanelRightClickMenu_PrepareCurrTrackMenu()
	-- level 2 menus
	if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
		TitanPanelRightClickMenu_AddTitle2(UIDROPDOWNMENU_MENU_VALUE, UIDROPDOWNMENU_MENU_LEVEL);
		TitanPanelCurrTrack_GatherFactions(TitanPanelCurrTrack_BuildFactionSubMenu);
		if UIDROPDOWNMENU_MENU_VALUE == "Options" then
			TitanPanelRightClickMenu_AddToggleVar2(TITCURRTRACK_SHOW_ANNOUNCE, TITCURRTRACK_ID, "ShowAnnounce");	
			TitanPanelRightClickMenu_AddToggleVar2(TITCURRTRACK_SHOW_LOG, TITCURRTRACK_ID, "ShowLog");	
			TitanPanelRightClickMenu_AddToggleVar2(TITCURRTRACK_SHOW_SUMMARY, TITCURRTRACK_ID, "ShowSummary");	
		end
		return;
	end
	-- level 1 menu
	TitanPanelRightClickMenu_AddTitle2(TitanPlugins[TITCURRTRACK_ID].menuText.." v"..TITCURRTRACK_VERSION);
	TitanPanelRightClickMenu_AddSpacer2();
	TitanPanelCurrTrack_GatherFactions(TitanPanelCurrTrack_BuildRightClickMenu);
	TitanPanelRightClickMenu_AddSpacer2();
	local info = {};
       	info.hasArrow = true; 
       	info.notCheckable = true;
       	info.text = "Options";
       	info.value = "Options";
	UIDropDownMenu_AddButton(info, 1);			
	TitanPanelRightClickMenu_AddSpacer2();
	info.text = "Close Menu";
	info.value = "Close Menu";
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info, 1);

end

function TitanCurrTrackHeaderFactionToggle(name)
	local value = "";
	local found = false;
	local array = TitanGetVar(TITCURRTRACK_ID, "TokenHeaders");
	for index, value in ipairs(array) do
		if (value == name) then
			found = index;
		end
	end
	if(found) then 
		tremove(array,found);		
	else
		tinsert(array,name);		
	end
	TitanSetVar(TITCURRTRACK_ID, "TokenHeaders", array)
	return;
end

function TitanPanelCurrTrack_BuildRightClickMenu(name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID, parentName)
	if(not isInactive) then
		if(isHeader and not isCollapsed) then
			command = {}
			command.text = name;
			command.value = name;
			command.hasArrow = 1;
			command.keepShownOnClick = 1;
			command.checked = function() if (tContains(TitanGetVar(TITCURRTRACK_ID, "TokenHeaders"), name)) then return nil else return true end end
			command.func = function() 
				TitanCurrTrackHeaderFactionToggle(name); 
				TitanPanelButton_UpdateButton(TITCURRTRACK_ID);
			end
			UIDropDownMenu_AddButton(command);
		end
	end
end

function TitanPanelCurrTrack_BuildFactionSubMenu(name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID, parentName)
	if(parentName == UIDROPDOWNMENU_MENU_VALUE and (not isHeader)) then
		command = {}
		command.text = " |T"..icon..":24|t "..name.." ("..count..")";
		command.value = name;
		command.checked = function() if (tContains(TitanGetVar(TITCURRTRACK_ID, "TokenHeaders"), name)) then return nil else return true end end
		command.func = function() 
			TitanCurrTrackHeaderFactionToggle(name); 
			TitanPanelButton_UpdateButton(TITCURRTRACK_ID);
		end
		UIDropDownMenu_AddButton(command, UIDROPDOWNMENU_MENU_LEVEL);
	end
end

function TitanPanelCurrTrack_Refresh()
	local parentName = "";
	local changed = "";
	local all = "";
	local name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID, cCount;
	cCount = GetCurrencyListSize();
	for index=1, cCount do 
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID = GetCurrencyListInfo(index);
		if (isHeader) then
			parentName = name;
		else
			if(not TITCURRTRACK_VALUES[name]) then
				TITCURRTRACK_VALUES[name] = count;
			end
			if (not tContains(TitanGetVar(TITCURRTRACK_ID, "TokenHeaders"), parentName) and
				not tContains(TitanGetVar(TITCURRTRACK_ID, "TokenHeaders"), name)) then 
				if(TITCURRTRACK_VALUES[name] ~= count) then
					local diff = count - TITCURRTRACK_VALUES[name];
					if(TITCURRTRACK_TTS[name]) then
						TITCURRTRACK_TTS[name] = TITCURRTRACK_TTS[name] + diff;
					else
						TITCURRTRACK_TTS[name] = diff;
					end
					if (diff > 0) then
						diff = TitanUtils_GetGreenText("+"..diff);
					else
						diff = TitanUtils_GetRedText(diff);
					end
					if(TitanGetVar(TITCURRTRACK_ID, "ShowAnnounce")) then
						changed = name.."\n"..diff.." |T"..icon..":32|t ("..count..")";
						UIErrorsFrame:AddMessage(changed, 2.0, 2.0, 0.0, 53, 5);
					end
					if(TitanGetVar(TITCURRTRACK_ID, "ShowLog")) then
						changed = " |T"..icon..":24|t "..TitanUtils_GetGoldText(name..": ")..diff.." ("..count..")";
						print(changed);
					end
					TITCURRTRACK_VALUES[name] = count;
					all = all.." |T"..icon..":24|t"..count.."("..diff..") ";
				else
					all = all.." |T"..icon..":24|t"..count.." ";
				end
			end
		end
	end
	if(all == "") then
		all = "CurrencyTracker";
	end;
	TITCURRTRACK_BUTTON_TEXT = all;
end

function TitanPanelCurrTrack_GatherFactions(method)
		local cCount = GetCurrencyListSize();
		local done = false;
		local index = 1;
		local parentName = "";
		while(not done)do
			local name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID = GetCurrencyListInfo(index);
			local value;
			-- Normalize values
			if(isHeader) then parentName = name; end;
			method(name, isHeader, isExpanded, isUnused, isWatched, count, icon, extraCurrencyType, itemID, parentName );
			index = index+1;
			if(index>cCount) then done = true; end;
		end		
end
